import _extend from 'lodash/extend';
import _bindAll from 'lodash/bindAll';
import _merge from 'lodash/merge';


/**
 * Hook class object.  The thing all definitions in /hooks are eventually instantiated as.
 *
 * @param {Object} definition Object describing the hooks methods and behavior
 * @constructor
 */
function Hook(definition) {
  this.config = {};
  _merge(this, definition || {});
  _bindAll(this);
}

_extend(Hook.prototype, {

  /**
   * Any attributes the hook needs added to the default configuration
   * Can be overridden in hook definitions.
   */
  defaults: {},

  /**
   * Function to store the core behavior for a hook.
   * Can be overridden in hook definitions.
   *
   * @returns {*}
   */
  load: function load() {}

});

export default Hook;