'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _lodash = require('lodash');

var _lodash2 = _interopRequireDefault(_lodash);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// todo: rename this to something like ActionTypeGenerator...

/**
 * Methods that generate ActionTypes using naming conventions. Used by action and
 * reducer blueprints.
 *
 * TODO: Since these functions generate ActionTypes, maybe rename it to
 * ActionTypeGenerator or ActionTypeFactory?
 *
 * Example Usage:
 * ADD_ITEM    = ActionType.add('item')
 * UPDATE_ITEM = ActionType.update('item')
 * REMOVE_ITEM = ActionType.remove('item')
 * FETCH_ITEM  = ActionType.fetch('item')
 * FETCH_ITEMS = ActionType.fetchPlural('item')
 *
 * @returns {Object} Set of functions to generate Action Types
 */

function formatModelName(modelName) {
  return _lodash2.default.snakeCase(modelName).toUpperCase();
}

exports.default = {
  add: function add(modelName) {
    return 'ADD_' + formatModelName(modelName);
  },

  update: function update(modelName) {
    return 'UPDATE_' + formatModelName(modelName);
  },

  remove: function remove(modelName) {
    return 'REMOVE_' + formatModelName(modelName);
  },

  fetch: function fetch(modelName) {
    return 'FETCH_' + formatModelName(modelName);
  },

  fetchPlural: function fetchPlural(modelName) {
    return 'FETCH_' + formatModelName(modelName) + 'S';
  },

  refetchPlural: function refetchPlural(modelName) {
    return 'REFETCH_' + formatModelName(modelName) + 'S';
  },

  reset: function reset(modelName) {
    return 'RESET_' + formatModelName(modelName);
  },

  RESET_STORE: 'RESET_STORE'
};
module.exports = exports['default'];