'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _lodash = require('lodash');

var _lodash2 = _interopRequireDefault(_lodash);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Hook class object.  The thing all definitions in /hooks are eventually instantiated as.
 *
 * @param {Object} definition Object describing the hooks methods and behavior
 * @constructor
 */
function Hook(definition) {
  this.config = {};
  _lodash2.default.merge(this, definition || {});
  _lodash2.default.bindAll(this);
}

_lodash2.default.extend(Hook.prototype, {

  /**
   * Any attributes the hook needs added to the default configuration
   * Can be overridden in hook definitions.
   */
  defaults: {},

  /**
   * Function to store the core behavior for a hook.
   * Can be overridden in hook definitions.
   *
   * @returns {*}
   */
  load: function load() {}

});

exports.default = Hook;
module.exports = exports['default'];