'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

exports.default = function (lore, modelName) {
  var config = lore.loader.loadModels()[modelName];
  var Models = lore.models;
  var Collections = lore.collections;
  var shouldNormalize = lore.config.actions.normalize;
  var attributes = config.attributes || {};

  function normalize(actions, model) {
    // if normalization is disabled, bail out
    if (!shouldNormalize) return;

    // iterate over attributes in the model config, looking for any models that need to
    // be normalized
    _lodash2.default.mapKeys(attributes, function (attribute, attributeName) {
      if (attribute.type !== 'model' && attribute.type !== 'models' && attribute.type !== 'collection') {
        return;
      }

      // get the name and instance of the model we need to normalize the attribute to
      var normalizedModelName = attribute.model;

      // log an error if no model was specified
      if (!normalizedModelName) {
        console.error('Attempted to normalize a [' + modelName + '] model but failed. No model name provided for the [' + attributeName + '] attribute');
        return;
      }

      // get the model this attribute should be normalized to
      var NormalizedModel = Models[normalizedModelName];

      // log an error if the model doesn't exist
      if (!NormalizedModel) {
        console.error('Attempted to normalize the [' + attributeName + '] for a [' + modelName + '] model but failed. No model exists named [' + normalizedModelName + ']');
        return;
      }

      if (attribute.type === 'model') {
        (0, _model3.default)(NormalizedModel, normalizedModelName, attributeName)(actions, model);
      }

      if (attribute.type === 'models') {
        (0, _models2.default)(NormalizedModel, normalizedModelName, attributeName)(actions, model);
      }

      if (attribute.type === 'collection') {
        // get the name and instance of the model we need to normalize the attribute to
        var normalizedCollectionName = attribute.model || attribute.collection;

        // log an error if no model was specified
        if (!normalizedCollectionName) {
          console.error('Attempted to normalize a [' + modelName + '] collection but failed. No collection name provided for the [' + attributeName + '] attribute');
          return;
        }

        // get the model this attribute should be normalized to
        var NormalizedCollection = Collections[normalizedCollectionName];

        // log an error if the model doesn't exist
        if (!NormalizedCollection) {
          console.error('Attempted to normalize the [' + attributeName + '] for a [' + modelName + '] collection but failed. No model exists named [' + normalizedCollectionName + ']');
          return;
        }

        (0, _collection3.default)(NormalizedCollection, normalizedCollectionName, attribute, attributeName)(actions, model);
      }
    });
  }

  return {
    model: function model(_model) {
      var actions = [];
      normalize(actions, _model);
      return actions;
    },

    collection: function collection(_collection) {
      var actions = [];
      _collection.models.forEach(function (model) {
        normalize(actions, model);
      });
      return actions;
    }
  };
};

var _lodash = require('lodash');

var _lodash2 = _interopRequireDefault(_lodash);

var _model2 = require('./model');

var _model3 = _interopRequireDefault(_model2);

var _models = require('./models');

var _models2 = _interopRequireDefault(_models);

var _collection2 = require('./collection');

var _collection3 = _interopRequireDefault(_collection2);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

module.exports = exports['default'];